@@ -5,7 +5,7 @@
  * should be used with the libcleri module.
  *
  * Source class: SiriGrammar
- * Created at: 2019-03-06 11:59:02
+ * Created at: 2020-01-23 14:08:47
  */
 #ifndef CLERI_EXPORT_SIRI_GRAMMAR_GRAMMAR_H_
 #define CLERI_EXPORT_SIRI_GRAMMAR_GRAMMAR_H_
@@ -145,6 +145,8 @@ enum cleri_grammar_ids {
     CLERI_GID_K_DURATION_NUM,
     CLERI_GID_K_END,
     CLERI_GID_K_ERROR,
+    CLERI_GID_K_EXPIRATION_LOG,
+    CLERI_GID_K_EXPIRATION_NUM,
     CLERI_GID_K_EXPRESSION,
     CLERI_GID_K_FALSE,
     CLERI_GID_K_FIFO_FILES,
@@ -282,6 +284,8 @@ enum cleri_grammar_ids {
     CLERI_GID_SET_ADDRESS,
     CLERI_GID_SET_BACKUP_MODE,
     CLERI_GID_SET_DROP_THRESHOLD,
+    CLERI_GID_SET_EXPIRATION_LOG,
+    CLERI_GID_SET_EXPIRATION_NUM,
     CLERI_GID_SET_EXPRESSION,
     CLERI_GID_SET_IGNORE_THRESHOLD,
     CLERI_GID_SET_LIST_LIMIT,
