@@ -124,9 +124,16 @@ int siridb_shards_add_points(
         siridb_series_t * series,
         siridb_points_t * points)
 {
+    _Bool is_num = siridb_series_isnum(series);
     siridb_shard_t * shard;
-    uint64_t duration = siridb_series_isnum(series) ?
-            siridb->duration_num : siridb->duration_log;
+
+    uv_mutex_lock(&siridb->values_mutex);
+
+    uint64_t duration = is_num ? siridb->duration_num : siridb->duration_log;
+    uint64_t expire_at = is_num ? siridb->exp_at_num : siridb->exp_at_log;
+
+    uv_mutex_unlock(&siridb->values_mutex);
+
     uint64_t shard_start, shard_end, shard_id;
     uint_fast32_t start, end, num_chunks, pstart, pend;
     uint16_t chunk_sz;
@@ -139,14 +146,24 @@ int siridb_shards_add_points(
         shard_end = shard_start + duration;
         shard_id = shard_start + series->mask;
 
+        for (   start = end;
+                end < points->len && points->data[end].ts < shard_end;
+                end++);
+
+        if (shard_end < expire_at)
+        {
+            series->length -= end - start;
+            series_update_start_end(series);
+            continue;
+        }
+
         if ((shard = imap_get(siridb->shards, shard_id)) == NULL)
         {
             shard = siridb_shard_create(
                     siridb,
                     shard_id,
                     duration,
-                    siridb_series_isnum(series) ?
-                            SIRIDB_SHARD_TP_NUMBER : SIRIDB_SHARD_TP_LOG,
+                    is_num ? SIRIDB_SHARD_TP_NUMBER : SIRIDB_SHARD_TP_LOG,
                     NULL);
             if (shard == NULL)
             {
@@ -154,10 +171,6 @@ int siridb_shards_add_points(
             }
         }
 
-        for (   start = end;
-                end < points->len && points->data[end].ts < shard_end;
-                end++);
-
         if (start != end)
         {
             size = end - start;
@@ -216,6 +229,52 @@ int siridb_shards_add_points(
     return siri_err;
 }
 
+double siridb_shards_count_percent(
+        siridb_t * siridb,
+        uint64_t end_ts,
+        uint8_t tp)
+{
+    size_t i;
+    double percent = 1.0;
+    vec_t * shards_list = NULL;
+    size_t count = 0;
+    size_t total = 0;
+    uint64_t duration = tp == SIRIDB_SHARD_TP_NUMBER
+            ? siridb->duration_num
+            : siridb->duration_log;
+
+    uv_mutex_lock(&siridb->shards_mutex);
+
+    if (siridb->shards->len == 0)
+    {
+        percent = 0.0;
+    }
+    else
+    {
+        shards_list = imap_2vec_ref(siridb->shards);
+    }
+
+    uv_mutex_unlock(&siridb->shards_mutex);
+
+    if (shards_list == NULL)
+        return percent;
+
+    for (i = 0; i < shards_list->len; i++)
+    {
+        siridb_shard_t * shard = (siridb_shard_t *) shards_list->data[i];
+        if (shard->tp == tp)
+        {
+            ++total;
+            count += ((shard->id - shard->id % duration) + duration) < end_ts;
+        }
+        siridb_shard_decref(shard);
+    }
+
+    percent = total ? (double) count / (double) total : 0.0;
+    vec_free(shards_list);
+    return percent;
+}
+
 /*
  * Returns true if fn is a shard filename, false if not.
  * Argument ext should be either ".sdb" or ".idx".
